@@ -2,14 +2,14 @@ package load;
 
 # Make sure we have version info for this module
 
-$VERSION  = '0.18';
+$VERSION  = '0.20';
 
 #--------------------------------------------------------------------------
 # No, we're NOT using strict here.  There are several reasons, the most
 # important being that strict bleeds into the string eval's that load.pm
 # is doing, causing compilation errors in all but the most simple modules.
-# If you _do_ want stricture as a developer of load.pm, simply activate the
-# line below here
+# If you _do_ want stricture as a developer of load.pm, simply de-activate
+# the lines of the BEGIN block below here
 #--------------------------------------------------------------------------
 BEGIN { # We're fooling the Kwalitee checker into thinking we're strict
 use strict;
@@ -97,11 +97,11 @@ sub register { $use{$_[1]} = ($use{$_[1]} || '')."use $_[2];" } #register
 sub import {
 
 # Obtain the class (so we can check whether load or AutoLoader usage)
-# Obtain the module name
+# Obtain caller info
 # Initialize the context flag
 
     my $class  = shift;
-    my ($module,$filename) = caller();
+    my ($module,undef,$lineno) = caller();
 
 # If there were any parameters specified
 #  Initialize the autoload export flag
@@ -189,11 +189,12 @@ sub import {
             *{$module.'::AUTOLOAD'} = \&AUTOLOAD if $autoload;
         }
 
-# Elseif called from a script
-#  Die indicating that doesn't make any sense
+# Elseif called from a script or from command line (no action from command line)
+#  Die indicating that doesn't make any sense if in a script
 
-    } elsif ($module eq 'main' and $filename ne '-e') {
-       die "Does not make sense to just 'use $class;' from your script";
+    } elsif ($module eq 'main') {
+       die "Does not make sense to just 'use $class;' from your script"
+         if $lineno;
 
 # Else (no parameters specified)
 #  Scan the source
@@ -527,6 +528,10 @@ load - control when subroutines will be loaded
 
   use load 'inherit';  # do NOT export AUTOLOAD handler to this namespace
 
+=head1 VERSION
+
+This documentation describes version 0.20.
+
 =head1 DESCRIPTION
 
 The "load" pragma allows a module developer to give the application developer
@@ -927,7 +932,7 @@ Please report bugs to <perlbugs@dijkmat.nl>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2005 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
+Copyright (c) 2002-2007 Elizabeth Mattijsen <liz@dijkmat.nl>. All rights
 reserved.  This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
